pyxmpp.stanzaprocessor

Package pyxmpp :: Module stanzaprocessor |
[hide private]

# Module stanzaprocessor

source code

Handling of XMPP stanzas.

Normative reference:
  - RFC 3920

Classes | [hide private]
| StanzaProcessor Universal stanza handler/router class.

Variables | [hide private]
| __revision__ = ``'``$Id: stanzaprocessor.py 714 2010-04-05 10:20:1``...``
| __package__ = ``'``pyxmpp``'``

Imports: libxml2, logging, threading, ExpiringDictionary, ProtocolError, BadRequestProtocolError, FeatureNotImplementedProtocolError, Stanza

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: stanzaprocessor.py 714 2010-04-05 10:20:10Z jajcus $'